﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Goldammer;

namespace Online_DigtalFilter {
    public partial class Form1 : Form {
        public Form1() {
            InitializeComponent();
        }

        MAIDevice m_firstDev = null;
        bool m_bMeasurement  = false;

        private void Form1_Load(object sender, EventArgs e) {
            m_firstDev = MAI.Devices[0];
            if (m_firstDev == null){
                MessageBox.Show("No Card found.");
                Close();
            }
            if (!m_firstDev.HasSoftwareExtension(SWExtension.Online_Filter)) {
                MessageBox.Show("This Card does not support Digital Filter Functions.");
                Close();
            }
            m_firstDev.ADChannels.ProcessDataBuffers += new MAIMeasurementBufferEvent(ADChannels_ProcessDataBuffers);
        }

        void ADChannels_ProcessDataBuffers(object obj, EventArgs args) {
            try {
                SetTextboxText("");

                uint NofValues = m_firstDev.ADChannels.GetNumberOfValues();
                double[] Values = null;
                foreach (MAIMeasurementChannelAD c in m_firstDev.ADChannels.GetMeasurementChannels()) {
                    Values = c.ReadData(NofValues);
                }
                if (Values == null)
                    return;
                string textboxtxt = "";
                for (int i = 0; i < 10; i++) {
                    if (i >= Values.Length)
                        return;
                    textboxtxt += Values[i].ToString() + Environment.NewLine;
                }
                SetTextboxText(textboxtxt);

            }
            catch (Exception ex) {
                MessageBox.Show(ex.Message);
            }
        }

        private void SetTextboxText(string AITextboxText) {
            if (InvokeRequired) {  // muss den Main-Thread "invoken", der Aufruf passiert ja aus dem Notification Thread heraus.
                MethodInvoker invoker = new MethodInvoker(delegate() {
                    textBox1.Text = AITextboxText;
                });
                Invoke(invoker);
            }
            else {
                textBox1.Text = AITextboxText;
            }
        }


        private void button1_Click(object sender, EventArgs e) {
            if (m_firstDev == null)
                return;
            m_firstDev.ADChannels.StopMeasurement();
            m_firstDev.ADChannels.StopNotificationThread();
            m_firstDev.ClearAllChannelLists();

            if (!m_bMeasurement) {
                MAIMeasurementChannelAD channel = m_firstDev.ADChannels[0].CreateMeasurementChannel(OversamplingMode.Disabled, GainFactor.Disabled, true);
                if (radioButtonFIR.Checked)
                    channel.Realtime.AddFIRFilter(FilterType.LOWPASS, 1000, 20.3, 0, false, 15, FIRWindow.Rectangular, 0, true);
                else if (radioButtonIIR.Checked)
                    channel.Realtime.AddIIRFilter(FilterType.LOWPASS, 1000, 20.3, 0, false, 0.9, 0.1, IIRFilterDesign.BUTTERWORTH, 5);

                m_firstDev.ADChannels.SetSampleRate(1000);
                m_firstDev.ADChannels.SetMeasurementBufferNotificationLevel(100);
                m_firstDev.ConfigMeasure();
                m_firstDev.ADChannels.StartNotificationThread();
                m_firstDev.ADChannels.StartMeasurement();
                m_bMeasurement = true;
                button1.Text = "Stop";
            }
            else {
                m_bMeasurement = false;
                button1.Text = "Start";

            }
           

        }
    }
}
